@@ -11,7 +11,7 @@ pub fn decode_hex(s: &str) -> Result<Vec<u8>, ParseIntError> {
 pub fn encode_hex(bytes: &[u8]) -> String {
     let mut s = String::with_capacity(bytes.len() * 2);
     for &b in bytes {
-        write!(s, "{:02x}", b).unwrap();
+        write!(s, "{:02x}", b).expect("failed to encode_hex");
     }
     s
 }
